@@ -45,13 +45,8 @@ def _get_product_from_detail(detail, product, contents, folder,
         iversion = product.version
         prodsource = product.source
         for content in contents:
-            matching_contents = product.getContentsMatching(content)
-            if not len(matching_contents):
-                sys.stderr.write('No %s for %s %s product.\n' %
-                                 (content, detail.id, product))
-                continue
-            content_name = matching_contents[0]
             if not list_only:
+                content_name = product.getContentName(content)
                 sversion = fmt % iversion
                 fname = '%s_%s_%s_%s' % (
                     eventid, prodsource, sversion, content_name)
@@ -135,7 +130,7 @@ def get_parser():
                         default='preferred')
     parser.add_argument('--get-source', dest='source', default='preferred',
                         help='Get contents for the "preferred" source, "all" sources, or a specific source ("us").')
-    parser.add_argument('--host', 
+    parser.add_argument('--host',
                         help='Specify a different comcat *search* host than earthquake.usgs.gov.')
     return parser
 
